## Version 0.2.0 (2024/05/08)


### Pull Requests Merged

#### Bugs fixed

* [PR 7](https://github.com/pytroll/pytroll-watchers/pull/7) - Fix missing uid in messages
* [PR 6](https://github.com/pytroll/pytroll-watchers/pull/6) - Log info when a message is sent

#### Features added

* [PR 10](https://github.com/pytroll/pytroll-watchers/pull/10) - Add sdist to pypi workflow
* [PR 9](https://github.com/pytroll/pytroll-watchers/pull/9) - Add a watcher for DHuS instances
* [PR 8](https://github.com/pytroll/pytroll-watchers/pull/8) - Add `path` to messages when `filesystem` is provided
* [PR 5](https://github.com/pytroll/pytroll-watchers/pull/5) - Add the datastore watcher
* [PR 4](https://github.com/pytroll/pytroll-watchers/pull/4) - Add copernicus dataspace watcher
* [PR 3](https://github.com/pytroll/pytroll-watchers/pull/3) - Add codecov, logging and aliasing
* [PR 2](https://github.com/pytroll/pytroll-watchers/pull/2) - Add cli and git-based version
* [PR 1](https://github.com/pytroll/pytroll-watchers/pull/1) - Refactor to use fix_times everywhere

In this release 10 pull requests were closed.
